function xdot = RLC_ode(x,u)
% ODE of a (serial) RLC circuit
% x(1): voltage over capacitor v_C
% x(2): electrical current i
% u: input voltage v

% Part of the solution of the Matlab exercise, Sheet 2
% (see http://syscop.de/teaching/2016/systemtheorie-und-regelungstechnik-1)

% AUTHOR: Florian Messerer
% Systems control and optimization laboratory, 
% Department of Microsystems Engineering (IMTEK),
% University of Freiburg
% 
% File Created: 16.05.2016

R = 25; % Ohm
L = .2; % Henry
C = 50e-6; % Farad

A = [0   1/C;
    -1/L -R/L];
B = [0; 1/L];

xdot = A*x + B*u;

%or
% v_C = x(1);
% i = x(2);
% xdot = zeros(2,1);
% xdot(1) = i/C;
% xdot(2) = 1/L*(u-R*i-v_C);
end